Transaction layer
=================

.. autoclass:: sipua.TransactionLayer
   :members:

.. autoclass:: sipua.ServerInviteTransaction()
   :members:
   :inherited-members:

.. autoclass:: sipua.ServerNonInviteTransaction()
   :members:
   :inherited-members:
